#This R-code accompanies software MMM for analysing a linear mixed model
#by Matti Pirinen, 2011,2012.

#This can be used for looking at the shapes of the prior distributions
#for any given set of parameters m,V,a and b.

#Prior distribution for parameters (beta,sigma^2) is NIG(m,V,a,b).
#I.e. Normal-inverse-gamma distribution with 
#mean-vector m=prior_exp
#variance-matrix V=prior_var
#shape parameter a=prior_d/2
#scale parameter b=prior_a/2

#for eta the prior is Beta(r,t)

#If quantitative phenotype is used, then look at the distributions of beta.
#If binary phenotype is used, then look at the distribution of logodds.


#For example: A Case-control study where 0.44 of individuals are cases.
#Goal: To find parameters such that prior on effect on log-odds scale is approx. N(0,0.2^2)
library(mvtnorm)
m=c(0.44,0)
V=diag(c(0.007,0.012))
b=0.8
a=5

#when interest is in testing z-predictors, prior on eta may be Beta(1,1)=Uniform(0,1)
r=1
t=1

#but when testing whether eta==0 (for example in region-based test in genetics),
#it may be reasonable to specify the alternative
#model that is concentrated closer to 0 rather than being distributed over the whole (0,1)
r=1.5
t=100



#sigma^(-2) has gamma(shape=a,rate=b)
#mode of sigma^2
b/(a+1)
#mean of sigma^2
b/(a-1)
#var of sigma^2
b^2/(a-1)^2/(a-2)

n=50000 #number of samples
sigma2=1/rgamma(n,shape=a,rate=b) #samples values for sigma^2
beta=matrix(0,ncol=2,nrow=n)
for(i in 1:n){beta[i,]=rmvnorm(1,m,sigma2[i]*V)} #samples values for intercept and slope

par(mfcol=c(2,3))
hist(beta[,1],breaks=100,main="intercept",xlab="")
hist(beta[,2],breaks=100,main="slope",xlab="")

logodds=beta[,2]/beta[,1]/(1-beta[,1])
hist(logodds,breaks=100,main=paste("log-odds (mu=",signif(mean(logodds),3),"sd=",signif(sd(logodds),3),")"))
hist(sqrt(sigma2),breaks=100,main="sigma",xlab="")

x=seq(0,1,length=10000)
plot(x,dbeta(x,r,t),t="l",xlab="eta",ylab="density",main=paste("eta (mu=",signif(r/(r+t),3),"sd=",signif(sqrt(r*t/(r+t)^2/(r+t+1)),3)))
